@@ -43,10 +43,6 @@ def create_dataset(tfrecords,
 
         - parallelize the map transformation.
 
-    Args:
-        csv_path ([type]): [description]
-        output ([type]): [description]
-
     Returns:
         tfrecords file
     """
@@ -55,7 +51,8 @@ def create_dataset(tfrecords,
 
     # pre-processing function but apply it in parallel on multiple samples.
     parsed_dataset = raw_dataset.map(
-        lambda example: _parse_tfrecords(example, height, width, depth, grid_h, grid_w, anchors, labels),
+        lambda example: _parse_tfrecords(example, height, width, depth, grid_h,
+                                         grid_w, anchors, labels),
         num_parallel_calls=tf.data.experimental.AUTOTUNE)
 
     parsed_dataset = parsed_dataset.shuffle(buffer_size, seed=seed)
@@ -85,23 +82,35 @@ def _parse_tfrecords(example, height, width, depth, grid_h, grid_w, anchors,
         'image_raw':
         tf.io.FixedLenFeature([], tf.string, default_value=""),
         'bbox_xmin':
-        tf.io.FixedLenSequenceFeature(
-            [], tf.float32, allow_missing=True, default_value=-1.0),
+        tf.io.FixedLenSequenceFeature([],
+                                      tf.float32,
+                                      allow_missing=True,
+                                      default_value=-1.0),
         'bbox_xmax':
-        tf.io.FixedLenSequenceFeature(
-            [], tf.float32, allow_missing=True, default_value=-1.0),
+        tf.io.FixedLenSequenceFeature([],
+                                      tf.float32,
+                                      allow_missing=True,
+                                      default_value=-1.0),
         'bbox_ymin':
-        tf.io.FixedLenSequenceFeature(
-            [], tf.float32, allow_missing=True, default_value=-1.0),
+        tf.io.FixedLenSequenceFeature([],
+                                      tf.float32,
+                                      allow_missing=True,
+                                      default_value=-1.0),
         'bbox_ymax':
-        tf.io.FixedLenSequenceFeature(
-            [], tf.float32, allow_missing=True, default_value=-1.0),
+        tf.io.FixedLenSequenceFeature([],
+                                      tf.float32,
+                                      allow_missing=True,
+                                      default_value=-1.0),
         'class':
-        tf.io.FixedLenSequenceFeature(
-            [], tf.string, allow_missing=True, default_value=""),
+        tf.io.FixedLenSequenceFeature([],
+                                      tf.string,
+                                      allow_missing=True,
+                                      default_value=""),
         'class_ids':
-        tf.io.FixedLenSequenceFeature(
-            [], tf.int64, allow_missing=True, default_value=-1)
+        tf.io.FixedLenSequenceFeature([],
+                                      tf.int64,
+                                      allow_missing=True,
+                                      default_value=-1)
     }
 
     # TODO Single example vs. batch example
@@ -209,8 +218,9 @@ def _find_best_anchor(center_w, center_h, anchors, n_anchors):
         intersect_h = min(float(center_h), float(anchor_heights[anchor]))
         # Calculate area - intersection
         intersect_area = intersect_w * intersect_h
-        union = float(center_w * center_h
-                      ) + anchor_widths[anchor] * anchor_heights[anchor]
+        union = float(
+            center_w *
+            center_h) + anchor_widths[anchor] * anchor_heights[anchor]
         iou_scores.append(intersect_area / union)
 
     # Index of best fit anchor box.
